<!--
Thanks for contributing to jupyterlab-deck!
Please fill out the following items to submit a pull request.

See the contributing guidelines for more information:
https://github.com/deathbeds/jupyterlab-deck/main/CONTRIBUTING.md
-->

## Checklist

- [ ] ran `doit lint` locally

## References

<!-- Note issue numbers this pull request addresses (should be at least one, see contributing guidelines above). -->

<!-- Note any other pull requests that address this issue and how this pull request is different. -->

## Code changes

<!-- Describe the code changes and how they address the issue. -->

## User-facing changes

<!-- Describe any visual or user interaction changes and how they address the issue. -->

<!-- For visual changes, include before and after screenshots here. -->

## Backwards-incompatible changes

<!-- Describe any backwards-incompatible changes to jupyterlab-deck public APIs. -->
